@@ -7,7 +7,7 @@ from .api_base import ApiBase
 class Preferences(ApiBase):
     """Class for Categories APIs."""
 
-    GET_PREFERENCES = '/preferences'
+    GET_PREFERENCES = '/preferences?minorversion=62'
 
     def get(self):
         """Get a list of the existing Preferences in the Organization.
